/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://public.eu-egee.org/partners/ for details on 
 * the copyright holders.
 * For license conditions see the license file or
 * http://eu-egee.org/license.html
 *
 * Authors: 
 *      Paolo Badino <Paolo.Badino@cern.ch>>
 *      Akos Frohner <Akos.Frohner@cern.ch>
 *      Peter Kunszt <Peter.Kunszt@cern.ch>
 *      Gavin McCance <Gavin.McCance@cern.ch>
 *      Krzysztof Nienartowicz <Krzysztof.Nienartowicz@cern.ch>
 *      Ricardo Rocha <Ricardo.Rocha@cern.ch>
 *      Jozsef Kovacs <smith@lutra.sztaki.hu>
 *      Daniel Rodrigues <Daniel.Rodrigues@cern.ch>
 */
package org.glite.data.catalog.service.fas;

import org.glite.data.catalog.service.AuthorizationException;
import org.glite.data.catalog.service.InternalException;
import org.glite.data.catalog.service.ExistsException;
import org.glite.data.catalog.service.NotExistsException;
import org.glite.data.catalog.service.PermissionEntry;
import org.glite.data.catalog.service.ServiceBase;

/**
 * The middleware level API for File Access (or Authorization) Service.
 *
 * @stereotype simple-interface
 */

public interface FAS extends FASBase {
    /**
     * Adds a GUID with the given permissions {BasicPermission,ACL} for a given GUID.
     * 
     * @param permissions - list of {guid, permission} pairs. 
     *                      The {@link org.glite.data.catalog.service.PermissionEntry PermissionEntry}
     *                      object takes the GUID as its principal and a list of ACLs.
     *                      This method sets the full permission, replacing all existing ACLs.
     * 
     * @throws AuthorizationException   Not allowed to insert a new GUID.
     * @throws ExistsException          This GUID is already in the catalog.
     */
    public void addGUID(PermissionEntry[] permissions) throws InternalException, AuthorizationException, ExistsException;


    /**
     * Remove GUID entries. 
     *  
     * @param guids The GUIDs to remove.
     * 
     * @throws AuthorizationException   Not allowed to remove the GUID.
     * @throws NotExistsException          This GUID does not exist in the catalog.
     */
    public void removeGUID(String guids[]) throws InternalException, AuthorizationException, NotExistsException;
}

